@@ -32,7 +32,7 @@ class SeedRecord(object):
 
     def to_file(self):
         if self.obj_name:
-            file = open("{}/{}.md".format(self.portal_dir, self.obj_name), 'a+')
+            file = open("{}/{}.md".format(self.portal_dir, self.obj_name), 'a+', encoding='utf-8')
             with file:
                 file.write("\n* {} : \n".format(self.id))
                 for field in self.fields:
